==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1ReplicaSetStatusFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1beta1ReplicaSetStatusFluentImpl<A extends V1beta1ReplicaSetStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1ReplicaSetStatusFluent<A>{

    private Integer availableReplicas;
    private List<V1beta1ReplicaSetConditionBuilder> conditions;
    private Integer fullyLabeledReplicas;
    private Long observedGeneration;
    private Integer readyReplicas;
    private Integer replicas;

    public V1beta1ReplicaSetStatusFluentImpl(){
    }
    public V1beta1ReplicaSetStatusFluentImpl(V1beta1ReplicaSetStatus instance){
            this.withAvailableReplicas(instance.getAvailableReplicas());

            this.withConditions(instance.getConditions());

            this.withFullyLabeledReplicas(instance.getFullyLabeledReplicas());

            this.withObservedGeneration(instance.getObservedGeneration());

            this.withReadyReplicas(instance.getReadyReplicas());

            this.withReplicas(instance.getReplicas());

    }

    public Integer getAvailableReplicas(){
            return this.availableReplicas;
    }

    public A withAvailableReplicas(Integer availableReplicas){
            this.availableReplicas=availableReplicas; return (A) this;
    }

    public Boolean hasAvailableReplicas(){
            return this.availableReplicas != null;
    }

    public A withNewAvailableReplicas(int arg1){
            return (A)withAvailableReplicas(new Integer(arg1));
    }

    public A withNewAvailableReplicas(String arg1){
            return (A)withAvailableReplicas(new Integer(arg1));
    }

    public A addToConditions(int index,V1beta1ReplicaSetCondition item){
            if (this.conditions == null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>();}
            V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.add(index >= 0 ? index : _visitables.size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
    }

    public A setToConditions(int index,V1beta1ReplicaSetCondition item){
            if (this.conditions == null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>();}
            V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);
            if (index < 0 || index >= _visitables.size()) { _visitables.add(builder); } else { _visitables.set(index, builder);}
            if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
             return (A)this;
    }

    public A addToConditions(V1beta1ReplicaSetCondition... items){
            if (this.conditions == null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>();}
            for (V1beta1ReplicaSetCondition item : items) {V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A addAllToConditions(Collection<V1beta1ReplicaSetCondition> items){
            if (this.conditions == null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>();}
            for (V1beta1ReplicaSetCondition item : items) {V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A removeFromConditions(V1beta1ReplicaSetCondition... items){
            for (V1beta1ReplicaSetCondition item : items) {V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    public A removeAllFromConditions(Collection<V1beta1ReplicaSetCondition> items){
            for (V1beta1ReplicaSetCondition item : items) {V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1ReplicaSetCondition> getConditions(){
            return build(conditions);
    }

    public List<V1beta1ReplicaSetCondition> buildConditions(){
            return build(conditions);
    }

    public V1beta1ReplicaSetCondition buildCondition(int index){
            return this.conditions.get(index).build();
    }

    public V1beta1ReplicaSetCondition buildFirstCondition(){
            return this.conditions.get(0).build();
    }

    public V1beta1ReplicaSetCondition buildLastCondition(){
            return this.conditions.get(conditions.size() - 1).build();
    }

    public V1beta1ReplicaSetCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1ReplicaSetConditionBuilder> predicate){
            for (V1beta1ReplicaSetConditionBuilder item: conditions) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public A withConditions(List<V1beta1ReplicaSetCondition> conditions){
            if (this.conditions != null) { _visitables.removeAll(this.conditions);}
            if (conditions != null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>(); for (V1beta1ReplicaSetCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
    }

    public A withConditions(V1beta1ReplicaSetCondition... conditions){
            if (this.conditions != null) {this.conditions.clear();}
            if (conditions != null) {for (V1beta1ReplicaSetCondition item :conditions){ this.addToConditions(item);}} return (A) this;
    }

    public Boolean hasConditions(){
            return conditions != null && !conditions.isEmpty();
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> addNewCondition(){
            return new ConditionsNestedImpl();
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> addNewConditionLike(V1beta1ReplicaSetCondition item){
            return new ConditionsNestedImpl(-1, item);
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1beta1ReplicaSetCondition item){
            return new ConditionsNestedImpl(index, item);
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> editCondition(int index){
            if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> editFirstCondition(){
            if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
            return setNewConditionLike(0, buildCondition(0));
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> editLastCondition(){
            int index = conditions.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1ReplicaSetConditionBuilder> predicate){
            int index = -1;
            for (int i=0;i<conditions.size();i++) { 
            if (predicate.apply(conditions.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public Integer getFullyLabeledReplicas(){
            return this.fullyLabeledReplicas;
    }

    public A withFullyLabeledReplicas(Integer fullyLabeledReplicas){
            this.fullyLabeledReplicas=fullyLabeledReplicas; return (A) this;
    }

    public Boolean hasFullyLabeledReplicas(){
            return this.fullyLabeledReplicas != null;
    }

    public A withNewFullyLabeledReplicas(int arg1){
            return (A)withFullyLabeledReplicas(new Integer(arg1));
    }

    public A withNewFullyLabeledReplicas(String arg1){
            return (A)withFullyLabeledReplicas(new Integer(arg1));
    }

    public Long getObservedGeneration(){
            return this.observedGeneration;
    }

    public A withObservedGeneration(Long observedGeneration){
            this.observedGeneration=observedGeneration; return (A) this;
    }

    public Boolean hasObservedGeneration(){
            return this.observedGeneration != null;
    }

    public A withNewObservedGeneration(String arg1){
            return (A)withObservedGeneration(new Long(arg1));
    }

    public A withNewObservedGeneration(long arg1){
            return (A)withObservedGeneration(new Long(arg1));
    }

    public Integer getReadyReplicas(){
            return this.readyReplicas;
    }

    public A withReadyReplicas(Integer readyReplicas){
            this.readyReplicas=readyReplicas; return (A) this;
    }

    public Boolean hasReadyReplicas(){
            return this.readyReplicas != null;
    }

    public A withNewReadyReplicas(int arg1){
            return (A)withReadyReplicas(new Integer(arg1));
    }

    public A withNewReadyReplicas(String arg1){
            return (A)withReadyReplicas(new Integer(arg1));
    }

    public Integer getReplicas(){
            return this.replicas;
    }

    public A withReplicas(Integer replicas){
            this.replicas=replicas; return (A) this;
    }

    public Boolean hasReplicas(){
            return this.replicas != null;
    }

    public A withNewReplicas(int arg1){
            return (A)withReplicas(new Integer(arg1));
    }

    public A withNewReplicas(String arg1){
            return (A)withReplicas(new Integer(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1ReplicaSetStatusFluentImpl that = (V1beta1ReplicaSetStatusFluentImpl) o;
            if (availableReplicas != null ? !availableReplicas.equals(that.availableReplicas) :that.availableReplicas != null) return false;
            if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
            if (fullyLabeledReplicas != null ? !fullyLabeledReplicas.equals(that.fullyLabeledReplicas) :that.fullyLabeledReplicas != null) return false;
            if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
            if (readyReplicas != null ? !readyReplicas.equals(that.readyReplicas) :that.readyReplicas != null) return false;
            if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
            return true;
    }


    public class ConditionsNestedImpl<N> extends V1beta1ReplicaSetConditionFluentImpl<V1beta1ReplicaSetStatusFluent.ConditionsNested<N>> implements V1beta1ReplicaSetStatusFluent.ConditionsNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1ReplicaSetConditionBuilder builder;
        private final int index;
    
            ConditionsNestedImpl(int index,V1beta1ReplicaSetCondition item){
                    this.index = index;
                    this.builder = new V1beta1ReplicaSetConditionBuilder(this, item);
            }
            ConditionsNestedImpl(){
                    this.index = -1;
                    this.builder = new V1beta1ReplicaSetConditionBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1ReplicaSetStatusFluentImpl.this.setToConditions(index, builder.build());
    }
    public N endCondition(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1ReplicaSetStatusFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1beta1ReplicaSetStatusFluentImpl<A extends V1beta1ReplicaSetStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1ReplicaSetStatusFluent<A>{

    private Integer availableReplicas;
    private List<V1beta1ReplicaSetConditionBuilder> conditions;
    private Integer fullyLabeledReplicas;
    private Long observedGeneration;
    private Integer readyReplicas;
    private Integer replicas;

    public V1beta1ReplicaSetStatusFluentImpl(){
    }
    public V1beta1ReplicaSetStatusFluentImpl(V1beta1ReplicaSetStatus instance){
            this.withAvailableReplicas(instance.getAvailableReplicas());

            this.withConditions(instance.getConditions());

            this.withFullyLabeledReplicas(instance.getFullyLabeledReplicas());

            this.withObservedGeneration(instance.getObservedGeneration());

            this.withReadyReplicas(instance.getReadyReplicas());

            this.withReplicas(instance.getReplicas());

    }

    public Integer getAvailableReplicas(){
            return this.availableReplicas;
    }

    public A withAvailableReplicas(Integer availableReplicas){
            this.availableReplicas=availableReplicas; return (A) this;
    }

    public Boolean hasAvailableReplicas(){
            return this.availableReplicas != null;
    }

    public A addToConditions(int index,V1beta1ReplicaSetCondition item){
            if (this.conditions == null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>();}
            V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
    }

    public A setToConditions(int index,V1beta1ReplicaSetCondition item){
            if (this.conditions == null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>();}
            V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);
            if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
            if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
             return (A)this;
    }

    public A addToConditions(V1beta1ReplicaSetCondition... items){
            if (this.conditions == null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>();}
            for (V1beta1ReplicaSetCondition item : items) {V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A addAllToConditions(Collection<V1beta1ReplicaSetCondition> items){
            if (this.conditions == null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>();}
            for (V1beta1ReplicaSetCondition item : items) {V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A removeFromConditions(V1beta1ReplicaSetCondition... items){
            for (V1beta1ReplicaSetCondition item : items) {V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    public A removeAllFromConditions(Collection<V1beta1ReplicaSetCondition> items){
            for (V1beta1ReplicaSetCondition item : items) {V1beta1ReplicaSetConditionBuilder builder = new V1beta1ReplicaSetConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1ReplicaSetCondition> getConditions(){
            return build(conditions);
    }

    public List<V1beta1ReplicaSetCondition> buildConditions(){
            return build(conditions);
    }

    public V1beta1ReplicaSetCondition buildCondition(int index){
            return this.conditions.get(index).build();
    }

    public V1beta1ReplicaSetCondition buildFirstCondition(){
            return this.conditions.get(0).build();
    }

    public V1beta1ReplicaSetCondition buildLastCondition(){
            return this.conditions.get(conditions.size() - 1).build();
    }

    public V1beta1ReplicaSetCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1ReplicaSetConditionBuilder> predicate){
            for (V1beta1ReplicaSetConditionBuilder item: conditions) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public Boolean hasMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1ReplicaSetConditionBuilder> predicate){
            for (V1beta1ReplicaSetConditionBuilder item: conditions) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withConditions(List<V1beta1ReplicaSetCondition> conditions){
            if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
            if (conditions != null) {this.conditions = new ArrayList<V1beta1ReplicaSetConditionBuilder>(); for (V1beta1ReplicaSetCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
    }

    public A withConditions(V1beta1ReplicaSetCondition... conditions){
            if (this.conditions != null) {this.conditions.clear();}
            if (conditions != null) {for (V1beta1ReplicaSetCondition item :conditions){ this.addToConditions(item);}} return (A) this;
    }

    public Boolean hasConditions(){
            return conditions != null && !conditions.isEmpty();
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> addNewCondition(){
            return new ConditionsNestedImpl();
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> addNewConditionLike(V1beta1ReplicaSetCondition item){
            return new ConditionsNestedImpl(-1, item);
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1beta1ReplicaSetCondition item){
            return new ConditionsNestedImpl(index, item);
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> editCondition(int index){
            if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> editFirstCondition(){
            if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
            return setNewConditionLike(0, buildCondition(0));
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> editLastCondition(){
            int index = conditions.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public V1beta1ReplicaSetStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1ReplicaSetConditionBuilder> predicate){
            int index = -1;
            for (int i=0;i<conditions.size();i++) { 
            if (predicate.apply(conditions.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
            return setNewConditionLike(index, buildCondition(index));
    }

    public Integer getFullyLabeledReplicas(){
            return this.fullyLabeledReplicas;
    }

    public A withFullyLabeledReplicas(Integer fullyLabeledReplicas){
            this.fullyLabeledReplicas=fullyLabeledReplicas; return (A) this;
    }

    public Boolean hasFullyLabeledReplicas(){
            return this.fullyLabeledReplicas != null;
    }

    public Long getObservedGeneration(){
            return this.observedGeneration;
    }

    public A withObservedGeneration(Long observedGeneration){
            this.observedGeneration=observedGeneration; return (A) this;
    }

    public Boolean hasObservedGeneration(){
            return this.observedGeneration != null;
    }

    public Integer getReadyReplicas(){
            return this.readyReplicas;
    }

    public A withReadyReplicas(Integer readyReplicas){
            this.readyReplicas=readyReplicas; return (A) this;
    }

    public Boolean hasReadyReplicas(){
            return this.readyReplicas != null;
    }

    public Integer getReplicas(){
            return this.replicas;
    }

    public A withReplicas(Integer replicas){
            this.replicas=replicas; return (A) this;
    }

    public Boolean hasReplicas(){
            return this.replicas != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1ReplicaSetStatusFluentImpl that = (V1beta1ReplicaSetStatusFluentImpl) o;
            if (availableReplicas != null ? !availableReplicas.equals(that.availableReplicas) :that.availableReplicas != null) return false;
            if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
            if (fullyLabeledReplicas != null ? !fullyLabeledReplicas.equals(that.fullyLabeledReplicas) :that.fullyLabeledReplicas != null) return false;
            if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
            if (readyReplicas != null ? !readyReplicas.equals(that.readyReplicas) :that.readyReplicas != null) return false;
            if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
            return true;
    }


    public class ConditionsNestedImpl<N> extends V1beta1ReplicaSetConditionFluentImpl<V1beta1ReplicaSetStatusFluent.ConditionsNested<N>> implements V1beta1ReplicaSetStatusFluent.ConditionsNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1ReplicaSetConditionBuilder builder;
        private final int index;
    
            ConditionsNestedImpl(int index,V1beta1ReplicaSetCondition item){
                    this.index = index;
                    this.builder = new V1beta1ReplicaSetConditionBuilder(this, item);
            }
            ConditionsNestedImpl(){
                    this.index = -1;
                    this.builder = new V1beta1ReplicaSetConditionBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1ReplicaSetStatusFluentImpl.this.setToConditions(index, builder.build());
    }
    public N endCondition(){
            return and();
    }

}


}
